LinkRunnerNativeBridge class

Native bridge for LinkRunner SDK Handles communication between Flutter and native iOS/Android SDKs

Constructors

LinkRunnerNativeBridge()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

capturePayment({required LRCapturePayment capturePayment}) → Future<void>
Capture payment
enablePIIHashing({required bool enabled}) → Future<void>
Enable or disable PII (Personally Identifiable Information) hashing
getAttributionData() → Future<AttributionData?>
Get attribution data from native SDK
Handle a deeplink for re-engagement attribution Call this method when the app is opened via a deeplink, regardless of app state
init(String token, String? secretKey, String? keyId, bool? disableIdfa, bool debug, [String platform = 'FLUTTER', String? packageVersion]) → Future<void>
Initialize the native SDK with project token Optionally pass the client SDK platform and version so native Android can be configured before init
isAaidCollectionDisabled() → Future<bool>
Check if AAID collection is currently disabled (Android only) Returns true if AAID collection is disabled, false otherwise
isNativeSDKAvailable() → Future<bool>
Check if native SDK is available
removePayment({required LRRemovePayment removePayment}) → Future<void>
Remove captured payment
setAdditionalData({required Map<String, dynamic> integrationData}) → Future<void>
Set additional integration data
setConsent(LRConsent consent) → Future<void>
Set the Google Ads consent state, normally from your Consent Management Platform. Supported on iOS and Android.
setCustomerUserId({required String userId}) → Future<void>
setDisableAaidCollection({required bool disabled}) → Future<void>
Disable AAID (Google Advertising ID) collection on Android This is useful for apps targeting children or families to comply with Google Play's Family Policy Note: This only affects Android. iOS uses disableIdfa parameter in init()
setPushToken({required String pushToken}) → Future<void>
Set push notification token for the current user
setUserData({required LRUserData userData}) → Future<void>
Set user data
signup({required LRUserData userData, Map<String, dynamic>? data}) → Future<void>
Trigger user signup event
trackEvent({required String eventName, Map<String, dynamic>? eventData, String? eventId}) → Future<void>
Track custom event