hasConsentForDataUsage property
Consent to send user data to Google for advertising purposes.
Sent as ad_user_data.
Implementation
final ConsentStatus hasConsentForDataUsage;
Consent to send user data to Google for advertising purposes.
Sent as ad_user_data.
final ConsentStatus hasConsentForDataUsage;