LRRemovePayment class

Constructors

LRRemovePayment({String? paymentId, String? userId})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
paymentId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited