LRUserData class

Constructors

LRUserData({required String id, String? name, String? phone, String? email, String? userCreatedAt, bool? isFirstTimeUser, String? mixpanelDistinctId, String? amplitudeDeviceId, String? posthogDistinctId, String? brazeDeviceId, String? gaAppInstanceId, String? gaSessionId, String? netcoreDeviceGuid})

Properties

amplitudeDeviceId → String?
final
brazeDeviceId → String?
final
email → String?
final
gaAppInstanceId → String?
final
gaSessionId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isFirstTimeUser → bool?
final
mixpanelDistinctId → String?
final
name → String?
final
netcoreDeviceGuid → String?
final
phone → String?
final
posthogDistinctId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userCreatedAt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited