handleDeeplink static method
Handle a deeplink for re-engagement attribution Call this method when the app is opened via a deeplink, regardless of app state
Implementation
static Future<DeeplinkData?> handleDeeplink({required String deeplinkUrl}) async {
try {
final result = await _channel.invokeMethod('handleDeeplink', {
'deeplinkUrl': deeplinkUrl,
});
if (result == null || (result is Map && result.isEmpty)) {
return null;
}
final Map<String, dynamic> resultMap = _convertToStringDynamicMap(result);
return DeeplinkData.fromJSON(resultMap);
} on PlatformException catch (e) {
developer.log('Failed to handle deeplink: ${e.message}',
error: e, name: packageName);
rethrow;
}
}